| Title: | Compute Price of Production and Labor Values |
|---|---|
| Description: | Computes the uniform rate of profit, the vector of price of production and the vector of direct prices; and also compute measures of deviation between market prices, direct prices and prices of production. <doi:10.1016/j.strueco.2026.03.009>. You provide the input-output data and 'clptheory' does the calculations for you. |
| Authors: | Deepankar Basu [aut, cre, cph] |
| Maintainer: | Deepankar Basu <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-05-17 05:18:42 UTC |
| Source: | https://github.com/dbasu-umass/clptheory |
Input Output Tables for the Australian economy from the World Input Output Database.
ausiotausiot
Input Output table for Australia for 15 years, 2000-2014.
ausiot[1:3,1:3]ausiot[1:3,1:3]
This is the socio economic accounts for the Australian economy extracted from the 2016 release of the World Input Output Database. It contains industry-level data on employment, capital stocks, gross output and value added at current and constant prices, in millions of local currency. The industry classification is consistent with the world input-output tables.
ausseaaussea
A industry-level (53 industries) data set for Australia over 15 years, 2000-2014.
Country code.
Industry code.
Description of the industry.
One of the following variables:
Gross output by industry at current basic prices (in millions of national currency).
Intermediate inputs at current purchasers' prices (in millions of national currency).
Gross value added at current basic prices (in millions of national currency).
Number of persons engaged (thousands).
Number of employees (thousands).
Total hours worked by employees (millions).
Compensation of employees (in millions of national currency).
Labour compensation (in millions of national currency).
Capital compensation (in millions of national currency).
Nominal capital stock (in millions of national currency).
Price levels gross output, 2010=100.
Price levels of intermediate inputs, 2010=100.
Price levels of gross value added, 2010=100.
Gross output, volume indices, 2010=100.
Intermediate inputs, volume indices, 2010=100.
Value added, volume indices, 2010=100.
Nominal exchange rate between the national currency and the US dollar.
summary(aussea$COMP)summary(aussea$COMP)
This function creates the data objects (matrices, vectors and scalars) necessary to implement the SI and NI from the WIOD.
createdata(country, year, datasea, dataio)createdata(country, year, datasea, dataio)
country |
country code as a character (e.g. "USA"). |
year |
year (eg. 2000). |
datasea |
the socio economic accounts (data frame). |
dataio |
the input-output (data frame). |
A list with the following elements:
Ahat |
The input-output matrix |
l |
The direct labor input vector (complex labor) |
l_simple |
The direct labor input vector (simple labor) |
Q |
The gross output vector |
wavg |
The average or uniform nominal wage rate |
wagevector_all |
The vector of nominal wage rates |
vlp |
Value of labor power |
b |
Real wage bundle (consumption/total hours) |
b1 |
Real wage bundle (share of PCE * min wage) |
pshare |
Average profit share |
createdata(country="USA",year=2010,datasea=usasea,dataio=usaiot)createdata(country="USA",year=2010,datasea=usasea,dataio=usaiot)
This function computes different measures of distance between prices of production (PP), market prices (MP) and direct prices (DP).
nonregdist(x, y, w, w_avg, Q)nonregdist(x, y, w, w_avg, Q)
x |
price of production vector (1 x n). |
y |
direct prices vector (1 x n). |
w |
vector of nominal wage rates (1 x n). |
w_avg |
average wage rate (scalar). |
Q |
gross output vector (1 x n) |
A list with the following elements:
rmseppmp |
RMSE between price of production and market prices |
rmsedpmp |
RMSE between direct prices and market prices |
rmseppdp |
RMSE between prices of production and direct prices |
madppmp |
MAD between price of production and market prices |
maddpmp |
MAD between direct prices and market prices |
madppdp |
MAD between prices of production and direct prices |
mawdppmp |
MAWD between price of production and market prices |
mawddpmp |
MAWD between direct prices and market prices |
mawdppdp |
MAWD between prices of production and direct prices |
angleppmp |
Angle between price of production and market prices |
angledpmp |
Angle between direct prices and market prices |
angleppdp |
Angle between prices of production and direct prices |
ddistppmp |
D-distance between price of production and market prices |
ddistdpmp |
D-distance between direct prices and market prices |
ddistppdp |
D-distance between prices of production and direct prices |
# ------ Data # price of production vector x<- matrix( data = c(0.25, 0.50, 0.75), nrow=1 ) # direct price vector y <- matrix( data = c(0.33, 0.275, 0.85), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # nominal wage rate vector w <- matrix( data = c(0.5, 0.33, 0.75), ncol=1 ) # average wage (scalar) w_avg <- 0.66 # Compute prices of production nonregdist(x = x, y = y, Q = Q, w = w, w_avg = w_avg)# ------ Data # price of production vector x<- matrix( data = c(0.25, 0.50, 0.75), nrow=1 ) # direct price vector y <- matrix( data = c(0.33, 0.275, 0.85), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # nominal wage rate vector w <- matrix( data = c(0.5, 0.33, 0.75), ncol=1 ) # average wage (scalar) w_avg <- 0.66 # Compute prices of production nonregdist(x = x, y = y, Q = Q, w = w, w_avg = w_avg)
This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the New Interpretation.
ppnewint1(A, w, v, Q, l_simple)ppnewint1(A, w, v, Q, l_simple)
A |
input-output matrix (n x n). |
w |
uniform nominal wage rate (scalar). |
v |
value of labor power (scalar) |
Q |
gross output vector (n x 1). |
l_simple |
vector of simple labor input (1 x n). |
A list with the following elements:
meig |
Maximum eigen value of A |
urop |
Uniform rate of profit (as a fraction) |
mrop |
Maximum rate of profit (as a fraction) |
pp |
Price of production vector |
dp |
Direct prices |
lvalues |
Labor values vector |
Anonneg |
Is A Nonnegative? (1=Y,0=N) |
Airred |
Is A Irreducible? (1=Y,0=N) |
# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Real wage bundle b <- matrix( data = c(0.0109, 0.0275, 0.296), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Direct labor input vector (simple) l_simple <- l # Market price vector m <- matrix(data = c(4, 60, 7),nrow=1) # Uniform nominal wage rate wavg <- m%*%b # Value of labor power v <- 2/3 # Compute prices of production ppnewint1(A = A,w = wavg[1,1],v=v,Q = Q,l_simple = l)# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Real wage bundle b <- matrix( data = c(0.0109, 0.0275, 0.296), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Direct labor input vector (simple) l_simple <- l # Market price vector m <- matrix(data = c(4, 60, 7),nrow=1) # Uniform nominal wage rate wavg <- m%*%b # Value of labor power v <- 2/3 # Compute prices of production ppnewint1(A = A,w = wavg[1,1],v=v,Q = Q,l_simple = l)
This function computes the uniform rate of profit, prices of production and labor values for a capital stock model using the New Interpretation.
ppnewint2(A, l, w, v, Q, D, K, t, Tax)ppnewint2(A, l, w, v, Q, D, K, t, Tax)
A |
input-output matrix (n x n). |
l |
vector of simple labor input (1 x n). |
w |
average nominal wage rate (scalar) |
v |
value of labor power (scalar) |
Q |
gross output vector (n x 1). |
D |
depreciation matrix (n x n). |
K |
capital stock coefficient matrix (n x n). |
t |
diagonal matrix of turnover rates (n x n). |
Tax |
matrix of tax rates (n x n). |
A list with the following elements:
meig |
Maximum eigen value of A |
urop |
Uniform rate of profit (as a fraction) |
mrop |
Maximum rate of profit (as a fraction) |
pp |
Price of production vector |
dp |
Direct prices |
lvalues |
Labor values vector |
Mnonneg |
Is M Nonnegative? (1=Y,0=N) |
Mirred |
Is M Irreducible? (1=Y,0=N) |
Nnonneg |
Is N Nonnegative? (1=Y,0=N) |
Nirred |
Is N Irreducible? (1=Y,0=N) |
MNirred |
Is M and N both Irreducible? (1=Y,0=N) |
# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Depreciation matrix D <- matrix( data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246), nrow = 3, ncol = 3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Value of labor power v <- 2/3 # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol = 1 ) # Capital stock coefficient matrix K <- matrix( data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043), nrow=3, ncol=3, byrow=TRUE ) # Diagonal matrix of turnover rates t <- diag(c(0.317, 0.099, 0.187)) # Matrix of tax rates (assumed 0 for this example) Tax <- matrix(0,nrow=3,ncol=3) # Average nominal wage rate w <- 3.765 # Compute prices of production ppnewint2(A=A,l=l,w=w,v=v,Q=Q,D=D,K=K,t=t,Tax=Tax)# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Depreciation matrix D <- matrix( data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246), nrow = 3, ncol = 3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Value of labor power v <- 2/3 # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol = 1 ) # Capital stock coefficient matrix K <- matrix( data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043), nrow=3, ncol=3, byrow=TRUE ) # Diagonal matrix of turnover rates t <- diag(c(0.317, 0.099, 0.187)) # Matrix of tax rates (assumed 0 for this example) Tax <- matrix(0,nrow=3,ncol=3) # Average nominal wage rate w <- 3.765 # Compute prices of production ppnewint2(A=A,l=l,w=w,v=v,Q=Q,D=D,K=K,t=t,Tax=Tax)
This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the Sraffian method.
ppsraffa1(A, Q, pshare, l_simple)ppsraffa1(A, Q, pshare, l_simple)
A |
input-output matrix (n x n). |
Q |
gross output vector (n x 1). |
pshare |
profit share (scalar) |
l_simple |
vector of simple labor input (1 x n). |
A list with the following elements:
meig |
Maximum eigen value of A |
urop |
Uniform rate of profit (as a fraction) |
mrop |
Maximum rate of profit (as a fraction) |
ppabs |
Price of production vector (absolute) |
pprel |
Price of production vector (relative) |
lvalues |
Labor values vector |
mevn |
Monetary expression of value using net output |
mevg |
Monetary expression of value using gross output |
Anonneg |
Is A Nonnegative? (1=Y,0=N) |
Airred |
Is A Irreducible? (1=Y,0=N) |
# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Direct labor input vector (simple) l_simple <- l # Profit share pshare <- 1/3 # Compute prices of production ppsraffa1(A = A,pshare=pshare,Q = Q,l_simple = l)# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Direct labor input vector (simple) l_simple <- l # Profit share pshare <- 1/3 # Compute prices of production ppsraffa1(A = A,pshare=pshare,Q = Q,l_simple = l)
This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the Standard Interpretation.
ppstdint1(A, b, Q, l_simple)ppstdint1(A, b, Q, l_simple)
A |
input-output matrix (n x n). |
b |
vector real wage bundle (n x 1). |
Q |
gross output vector (n x 1). |
l_simple |
vector of simple labor input (1 x n). |
A list with the following elements:
meig |
Maximum eigen value of M |
urop |
Uniform rate of profit (as a fraction) |
mrop |
Maximum rate of profit (as a fraction) |
pp |
Price of production vector |
dp |
Direct prices |
lvalues |
Labor values vector |
Mnonneg |
Is M Nonnegative? (1=Y,0=N) |
Mirred |
Is M Irreducible? (1=Y,0=N) |
# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Real wage bundle b <- matrix( data = c(0.0109, 0.0275, 0.296), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Direct labor input vector (simple) l_simple <- l # Compute prices of production ppstdint1(A = A,b = b,Q = Q,l_simple = l)# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Real wage bundle b <- matrix( data = c(0.0109, 0.0275, 0.296), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Direct labor input vector (simple) l_simple <- l # Compute prices of production ppstdint1(A = A,b = b,Q = Q,l_simple = l)
This function computes the uniform rate of profit, prices of production and labor values for a capital stock model using the Standard Interpretation.
ppstdint2(A, l, b, Q, D, K, t, Tax)ppstdint2(A, l, b, Q, D, K, t, Tax)
A |
input-output matrix (n x n). |
l |
vector of simple labor input (1 x n). |
b |
vector real wage bundle (n x 1). |
Q |
gross output vector (n x 1). |
D |
depreciation matrix (n x n). |
K |
capital stock coefficient matrix (n x n). |
t |
diagonal matrix of turnover rates (n x n). |
Tax |
matrix of tax rates (n x n). |
A list with the following elements:
meig |
Maximum eigen value of M |
urop |
Uniform rate of profit (as a fraction) |
mrop |
Maximum rate of profit (as a fraction) |
pp |
Price of production vector |
dp |
Direct prices |
lvalues |
Labor values vector |
Mnonneg |
Is M Nonnegative? (1=Y,0=N) |
Mirred |
Is M Irreducible? (1=Y,0=N) |
# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Depreciation matrix D <- matrix( data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246), nrow = 3, ncol = 3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Real wage bundle b <- matrix( data = c(0.0109, 0.0275, 0.296), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol = 1 ) # Capital stock coefficient matrix K <- matrix( data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043), nrow=3, ncol=3, byrow=TRUE ) # Diagonal matrix of turnover rates t <- diag(c(0.317, 0.099, 0.187)) # Matrix of tax rates (assumed 0) Tax <- matrix(0,nrow=3,ncol=3) # Compute prices of production ppstdint2(A=A,l=l,b=b,Q=Q,D=D,K=K,t=t,Tax=Tax)# ------ Data # Input-output matrix A <- matrix( data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165), nrow=3, ncol=3, byrow = TRUE ) # Depreciation matrix D <- matrix( data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246), nrow = 3, ncol = 3, byrow = TRUE ) # Direct labor input vector (complex) l <- matrix( data = c(0.193, 3.562, 0.616), nrow=1 ) # Real wage bundle b <- matrix( data = c(0.0109, 0.0275, 0.296), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol=1 ) # Gross output vector Q <- matrix( data = c(26530, 18168, 73840), ncol = 1 ) # Capital stock coefficient matrix K <- matrix( data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043), nrow=3, ncol=3, byrow=TRUE ) # Diagonal matrix of turnover rates t <- diag(c(0.317, 0.099, 0.187)) # Matrix of tax rates (assumed 0) Tax <- matrix(0,nrow=3,ncol=3) # Compute prices of production ppstdint2(A=A,l=l,b=b,Q=Q,D=D,K=K,t=t,Tax=Tax)
Input Output Tables for the US economy from the World Input Output Database.
usaiotusaiot
Input Output table for USA for 15 years, 2000-2014.
usaiot[1:5,1:5]usaiot[1:5,1:5]
Personal Consumption Expenditure from the Input Output Table for the USA. This data is used to construct the real wage bundle for computing the price of production vector.
usarwbusarwb
Consumption expenditure on the output of 53 industries for USA for 15 years, 2000-2014.
data(usarwb)data(usarwb)
This is the socio economic accounts for the USA extracted from the 2016 release of the World Input Output Database. It contains industry-level data on employment, capital stocks, gross output and value added at current and constant prices, in millions of local currency. The industry classification is consistent with the world input-output tables.
usaseausasea
A industry-level (53 industries) data set for USA over 15 years, 2000-2014.
Country code.
Industry code.
Description of the industry.
One of the following variables:
Gross output by industry at current basic prices (in millions of national currency).
Intermediate inputs at current purchasers' prices (in millions of national currency).
Gross value added at current basic prices (in millions of national currency).
Number of persons engaged (thousands).
Number of employees (thousands).
Total hours worked by employees (millions).
Compensation of employees (in millions of national currency).
Labour compensation (in millions of national currency).
Capital compensation (in millions of national currency).
Nominal capital stock (in millions of national currency).
Price levels gross output, 2010=100.
Price levels of intermediate inputs, 2010=100.
Price levels of gross value added, 2010=100.
Gross output, volume indices, 2010=100.
Intermediate inputs, volume indices, 2010=100.
Value added, volume indices, 2010=100.
Nominal exchange rate between the national currency and the US dollar.
summary(usasea$COMP)summary(usasea$COMP)