Title: Compute Price of Production and Labor Values
Version: 1.0.0
Description: Computes the uniform rate of profit, the vector of price of production and the vector of direct prices; and also compute measures of deviation between market prices, direct prices and prices of production. <doi:10.1016/j.strueco.2026.03.009>. You provide the input-output data and 'clptheory' does the calculations for you.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: popdemo, stats, dplyr, magrittr
Depends: R (≥ 2.10)
LazyData: true
Suggests: knitr, rmarkdown
URL: https://github.com/dbasu-umass/clptheory/
NeedsCompilation: no
Packaged: 2026-03-18 00:25:55 UTC; dbasu
Author: Deepankar Basu [aut, cre, cph]
Maintainer: Deepankar Basu <dbasu@umass.edu>
Repository: CRAN
Date/Publication: 2026-03-18 00:40:02 UTC

AUS IO Table

Description

Input Output Tables for the Australian economy from the World Input Output Database.

Usage

ausiot

Format

Input Output table for Australia for 15 years, 2000-2014.

doi:10.34894/PJ2M1C

Examples

ausiot[1:3,1:3]

Socio Economic Accounts

Description

This is the socio economic accounts for the Australian economy extracted from the 2016 release of the World Input Output Database. It contains industry-level data on employment, capital stocks, gross output and value added at current and constant prices, in millions of local currency. The industry classification is consistent with the world input-output tables.

Usage

aussea

Format

A industry-level (53 industries) data set for Australia over 15 years, 2000-2014.

country

Country code.

code

Industry code.

description

Description of the industry.

variable

One of the following variables:

GO

Gross output by industry at current basic prices (in millions of national currency).

II

Intermediate inputs at current purchasers' prices (in millions of national currency).

VA

Gross value added at current basic prices (in millions of national currency).

EMP

Number of persons engaged (thousands).

EMPE

Number of employees (thousands).

H_EMPE

Total hours worked by employees (millions).

COMP

Compensation of employees (in millions of national currency).

LAB

Labour compensation (in millions of national currency).

CAP

Capital compensation (in millions of national currency).

K

Nominal capital stock (in millions of national currency).

GO_PI

Price levels gross output, 2010=100.

II_PI

Price levels of intermediate inputs, 2010=100.

VA_PI

Price levels of gross value added, 2010=100.

GO_QI

Gross output, volume indices, 2010=100.

II_QI

Intermediate inputs, volume indices, 2010=100.

VA_QI

Value added, volume indices, 2010=100.

NOMEXCH

Nominal exchange rate between the national currency and the US dollar.

doi:10.34894/PJ2M1C

Examples

summary(aussea$COMP)

Create data set for analysis.

Description

This function creates the data objects (matrices, vectors and scalars) necessary to implement the SI and NI from the WIOD.

Usage

createdata(country, year, datasea, dataio)

Arguments

country

country code as a character (e.g. "USA").

year

year (eg. 2000).

datasea

the socio economic accounts (data frame).

dataio

the input-output (data frame).

Value

A list with the following elements:

Ahat

The input-output matrix

l

The direct labor input vector (complex labor)

l_simple

The direct labor input vector (simple labor)

Q

The gross output vector

wavg

The average or uniform nominal wage rate

wagevector_all

The vector of nominal wage rates

vlp

Value of labor power

b

Real wage bundle (consumption/total hours)

b1

Real wage bundle (share of PCE * min wage)

pshare

Average profit share

Examples


createdata(country="USA",year=2010,datasea=usasea,dataio=usaiot)



Nonregression-based measures of distance between MP, DP, PP

Description

This function computes different measures of distance between prices of production (PP), market prices (MP) and direct prices (DP).

Usage

nonregdist(x, y, w, w_avg, Q)

Arguments

x

price of production vector (1 x n).

y

direct prices vector (1 x n).

w

vector of nominal wage rates (1 x n).

w_avg

average wage rate (scalar).

Q

gross output vector (1 x n)

Value

A list with the following elements:

rmseppmp

RMSE between price of production and market prices

rmsedpmp

RMSE between direct prices and market prices

rmseppdp

RMSE between prices of production and direct prices

madppmp

MAD between price of production and market prices

maddpmp

MAD between direct prices and market prices

madppdp

MAD between prices of production and direct prices

mawdppmp

MAWD between price of production and market prices

mawddpmp

MAWD between direct prices and market prices

mawdppdp

MAWD between prices of production and direct prices

angleppmp

Angle between price of production and market prices

angledpmp

Angle between direct prices and market prices

angleppdp

Angle between prices of production and direct prices

ddistppmp

D-distance between price of production and market prices

ddistdpmp

D-distance between direct prices and market prices

ddistppdp

D-distance between prices of production and direct prices

Examples


# ------ Data

# price of production vector
x<- matrix(
data = c(0.25, 0.50, 0.75),
nrow=1
)
# direct price vector
y <- matrix(
data = c(0.33, 0.275, 0.85),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# nominal wage rate vector
w <- matrix(
data = c(0.5, 0.33, 0.75),
ncol=1
)
# average wage (scalar)
w_avg <- 0.66
# Compute prices of production
nonregdist(x = x, y = y, Q = Q, w = w, w_avg = w_avg)


Circulating capital model using the New Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the New Interpretation.

Usage

ppnewint1(A, w, v, Q, l_simple)

Arguments

A

input-output matrix (n x n).

w

uniform nominal wage rate (scalar).

v

value of labor power (scalar)

Q

gross output vector (n x 1).

l_simple

vector of simple labor input (1 x n).

Value

A list with the following elements:

meig

Maximum eigen value of A

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Anonneg

Is A Nonnegative? (1=Y,0=N)

Airred

Is A Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Real wage bundle
b <- matrix(
data = c(0.0109, 0.0275, 0.296),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Direct labor input vector (simple)
l_simple <- l
# Market price vector
m <- matrix(data = c(4, 60, 7),nrow=1)
# Uniform nominal wage rate
wavg <- m%*%b
# Value of labor power
v <- 2/3
# Compute prices of production
ppnewint1(A = A,w = wavg[1,1],v=v,Q = Q,l_simple = l)


Capital stock model using the New Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a capital stock model using the New Interpretation.

Usage

ppnewint2(A, l, w, v, Q, D, K, t, Tax)

Arguments

A

input-output matrix (n x n).

l

vector of simple labor input (1 x n).

w

average nominal wage rate (scalar)

v

value of labor power (scalar)

Q

gross output vector (n x 1).

D

depreciation matrix (n x n).

K

capital stock coefficient matrix (n x n).

t

diagonal matrix of turnover rates (n x n).

Tax

matrix of tax rates (n x n).

Value

A list with the following elements:

meig

Maximum eigen value of A

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Mnonneg

Is M Nonnegative? (1=Y,0=N)

Mirred

Is M Irreducible? (1=Y,0=N)

Nnonneg

Is N Nonnegative? (1=Y,0=N)

Nirred

Is N Irreducible? (1=Y,0=N)

MNirred

Is M and N both Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Depreciation matrix
D <- matrix(
data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246),
nrow = 3, ncol = 3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Value of labor power
v <- 2/3
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Gross output vector 
Q <- matrix(
data = c(26530, 18168, 73840),
ncol = 1
)
# Capital stock coefficient matrix
K <- matrix(
data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043),
nrow=3, ncol=3, byrow=TRUE
)
# Diagonal matrix of turnover rates
t <- diag(c(0.317, 0.099, 0.187))
# Matrix of tax rates (assumed 0 for this example)
Tax <- matrix(0,nrow=3,ncol=3)
# Average nominal wage rate
w <- 3.765
# Compute prices of production
ppnewint2(A=A,l=l,w=w,v=v,Q=Q,D=D,K=K,t=t,Tax=Tax)


Circulating capital model using the Sraffian method.

Description

This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the Sraffian method.

Usage

ppsraffa1(A, Q, pshare, l_simple)

Arguments

A

input-output matrix (n x n).

Q

gross output vector (n x 1).

pshare

profit share (scalar)

l_simple

vector of simple labor input (1 x n).

Value

A list with the following elements:

meig

Maximum eigen value of A

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

ppabs

Price of production vector (absolute)

pprel

Price of production vector (relative)

lvalues

Labor values vector

mevn

Monetary expression of value using net output

mevg

Monetary expression of value using gross output

Anonneg

Is A Nonnegative? (1=Y,0=N)

Airred

Is A Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Direct labor input vector (simple)
l_simple <- l
# Profit share
pshare <- 1/3
# Compute prices of production
ppsraffa1(A = A,pshare=pshare,Q = Q,l_simple = l)


Circulating capital model using the Standard Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a basic circulating capital model using the Standard Interpretation.

Usage

ppstdint1(A, b, Q, l_simple)

Arguments

A

input-output matrix (n x n).

b

vector real wage bundle (n x 1).

Q

gross output vector (n x 1).

l_simple

vector of simple labor input (1 x n).

Value

A list with the following elements:

meig

Maximum eigen value of M

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Mnonneg

Is M Nonnegative? (1=Y,0=N)

Mirred

Is M Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Real wage bundle
b <- matrix(
data = c(0.0109, 0.0275, 0.296),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Direct labor input vector (simple)
l_simple <- l
# Compute prices of production
ppstdint1(A = A,b = b,Q = Q,l_simple = l)


Capital stock model using the Standard Interpretation.

Description

This function computes the uniform rate of profit, prices of production and labor values for a capital stock model using the Standard Interpretation.

Usage

ppstdint2(A, l, b, Q, D, K, t, Tax)

Arguments

A

input-output matrix (n x n).

l

vector of simple labor input (1 x n).

b

vector real wage bundle (n x 1).

Q

gross output vector (n x 1).

D

depreciation matrix (n x n).

K

capital stock coefficient matrix (n x n).

t

diagonal matrix of turnover rates (n x n).

Tax

matrix of tax rates (n x n).

Value

A list with the following elements:

meig

Maximum eigen value of M

urop

Uniform rate of profit (as a fraction)

mrop

Maximum rate of profit (as a fraction)

pp

Price of production vector

dp

Direct prices

lvalues

Labor values vector

Mnonneg

Is M Nonnegative? (1=Y,0=N)

Mirred

Is M Irreducible? (1=Y,0=N)

Examples


# ------ Data
# Input-output matrix
A <- matrix(
data = c(0.265,0.968,0.00681,0.0121,0.391,0.0169,0.0408,0.808,0.165),
nrow=3, ncol=3, byrow = TRUE
)
# Depreciation matrix
D <- matrix(
data = c(0,0,0,0.00568,0.0267,0.0028,0.00265,0.0147,0.00246),
nrow = 3, ncol = 3, byrow = TRUE
)
# Direct labor input vector (complex)
l <- matrix(
data = c(0.193, 3.562, 0.616),
nrow=1
)
# Real wage bundle
b <- matrix(
data = c(0.0109, 0.0275, 0.296),
ncol=1
)
# Gross output vector
Q <- matrix(
data = c(26530, 18168, 73840),
ncol=1
)
# Gross output vector 
Q <- matrix(
data = c(26530, 18168, 73840),
ncol = 1
)
# Capital stock coefficient matrix
K <- matrix(
data = c(0,0,0,0.120,0.791,0.096,0.037,0.251,0.043),
nrow=3, ncol=3, byrow=TRUE
)
# Diagonal matrix of turnover rates
t <- diag(c(0.317, 0.099, 0.187))
# Matrix of tax rates (assumed 0)
Tax <- matrix(0,nrow=3,ncol=3)

# Compute prices of production
ppstdint2(A=A,l=l,b=b,Q=Q,D=D,K=K,t=t,Tax=Tax)

USA IO Table

Description

Input Output Tables for the US economy from the World Input Output Database.

Usage

usaiot

Format

Input Output table for USA for 15 years, 2000-2014.

doi:10.34894/PJ2M1C

Examples

usaiot[1:5,1:5]

Real Wage Bundle, USA

Description

Personal Consumption Expenditure from the Input Output Table for the USA. This data is used to construct the real wage bundle for computing the price of production vector.

Usage

usarwb

Format

Consumption expenditure on the output of 53 industries for USA for 15 years, 2000-2014.

doi:10.34894/PJ2M1C

Examples

data(usarwb)

Socio Economic Accounts

Description

This is the socio economic accounts for the USA extracted from the 2016 release of the World Input Output Database. It contains industry-level data on employment, capital stocks, gross output and value added at current and constant prices, in millions of local currency. The industry classification is consistent with the world input-output tables.

Usage

usasea

Format

A industry-level (53 industries) data set for USA over 15 years, 2000-2014.

country

Country code.

code

Industry code.

description

Description of the industry.

variable

One of the following variables:

GO

Gross output by industry at current basic prices (in millions of national currency).

II

Intermediate inputs at current purchasers' prices (in millions of national currency).

VA

Gross value added at current basic prices (in millions of national currency).

EMP

Number of persons engaged (thousands).

EMPE

Number of employees (thousands).

H_EMPE

Total hours worked by employees (millions).

COMP

Compensation of employees (in millions of national currency).

LAB

Labour compensation (in millions of national currency).

CAP

Capital compensation (in millions of national currency).

K

Nominal capital stock (in millions of national currency).

GO_PI

Price levels gross output, 2010=100.

II_PI

Price levels of intermediate inputs, 2010=100.

VA_PI

Price levels of gross value added, 2010=100.

GO_QI

Gross output, volume indices, 2010=100.

II_QI

Intermediate inputs, volume indices, 2010=100.

VA_QI

Value added, volume indices, 2010=100.

NOMEXCH

Nominal exchange rate between the national currency and the US dollar.

doi:10.34894/PJ2M1C

Examples

summary(usasea$COMP)

mirror server hosted at Truenetwork, Russian Federation.